==> freecad_0.20.2+dfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Tux/Resources/translations/Tux_pt-PT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt-PT" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Select</source>
      <translation>Selecionar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Zoom</source>
      <translation>Zoom</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotate</source>
      <translation>Rodar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Pan</source>
      <translation>Arrastar vista (pan)</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Tilt</source>
      <translation>Inclinação</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="72"/>
      <source>Navigation style</source>
      <translation>Estilo de navegação</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="73"/>
      <source>Page Up or Page Down key.</source>
      <translation>Tecla Page Up ou Page Down.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Rotation focus</source>
      <translation>Foco de rotação</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="75"/>
      <source>Middle mouse button or H key.</source>
      <translation>Botão do meio do rato ou a tecla H.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="77"/>
      <source>Middle mouse button.</source>
      <translation>Botão do meio do rato.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="80"/>
      <source>Navigation style not recognized.</source>
      <translation>Estilo de navegação não reconhecido.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="331"/>
      <source>Settings</source>
      <translation>Ajustes</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="332"/>
      <source>Orbit style</source>
      <translation>Estilo da Órbita</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="333"/>
      <source>Compact</source>
      <translation>Compacto</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="334"/>
      <source>Tooltip</source>
      <translation>Sugestão</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="335"/>
      <source>Turntable</source>
      <translation>Plataforma giratória</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="336"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="337"/>
      <source>Undefined</source>
      <translation>Indefinido</translation>
    </message>
  </context>
</TS>

==> freecad_0.21.2+dfsg1.orig.tar.xz: FreeCAD-0.21.2/src/Mod/Tux/Resources/translations/Tux_pt-PT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt-PT" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Select</source>
      <translation>Selecionar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Zoom</source>
      <translation>Zoom</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotate</source>
      <translation>Rodar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Pan</source>
      <translation>Arrastar vista (pan)</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Tilt</source>
      <translation>Inclinação</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="72"/>
      <source>Navigation style</source>
      <translation>Estilo de navegação</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="73"/>
      <source>Page Up or Page Down key.</source>
      <translation>Tecla Page Up ou Page Down.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Rotation focus</source>
      <translation>Foco de rotação</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="75"/>
      <source>Middle mouse button or H key.</source>
      <translation>Botão do meio do rato ou a tecla H.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="77"/>
      <source>Middle mouse button.</source>
      <translation>Botão do meio do rato.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="80"/>
      <source>Navigation style not recognized.</source>
      <translation>Estilo de navegação não reconhecido.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="331"/>
      <source>Settings</source>
      <translation>Ajustes</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="332"/>
      <source>Orbit style</source>
      <translation>Estilo da Órbita</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="333"/>
      <source>Compact</source>
      <translation>Compacto</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="334"/>
      <source>Tooltip</source>
      <translation>Sugestão</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="335"/>
      <source>Turntable</source>
      <translation>Plataforma giratória</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="336"/>
      <source>Free Turntable</source>
      <translation type="unfinished">Free Turntable</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="337"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="338"/>
      <source>Undefined</source>
      <translation>Indefinido</translation>
    </message>
  </context>
</TS>
